/**
 * Based on examples in
 *     Head First Object-Oriented Analysis and Design
 *     by Brett D. McLaughlin, Gary Pollice, and David West
 *     O'Reilly, 2007
 *     ISBN 978-0-596-00867-3
 *
 * Ported from Java by
 *     Ronald Mak
 *     Department of Computer Engineering
 *     San Jose State University
 *     San Jose, CA  95192
 */
#ifndef GUITAR_H_
#define GUITAR_H_

#include <string>
#include "GuitarSpec.h"
#include "Builder.h"
#include "Type.h"
#include "Wood.h"

using namespace std;

class Guitar
{
private:
    string serial_number, model;
    double price;
    GuitarSpec *spec;

public:
    Guitar(string serial_number, double price,
           Builder builder, string model, Type type,
           int string_count, Wood back_wood, Wood top_wood)
    : serial_number(serial_number), price(price),
      spec(new GuitarSpec(builder, model, type, string_count,
                          back_wood, top_wood))
    {}

    string get_serial_number() const { return serial_number; }
    double get_price() const { return price; }
    void   set_price(float new_price) { price = new_price; }
    GuitarSpec *get_spec() const { return spec; }
};

#endif /* GUITAR_H_ */
